package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsCapacity;
import com.steerinfo.dil.service.impl.RmsCapacityServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:ZhouZhou
 * @CreateTime:2021/11/9 14:28
 * @Version:V1.0
 */
@RestController
@RequestMapping("/${api.version}/rmscapacity")
public class RmsCapacityController extends BaseRESTfulController {
    @Autowired
    RmsCapacityServiceImpl rmsCapacityService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;


    /**
     * 创建运力信息
     * @param rmsCapacity
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsCapacity对象创建")
    @ApiImplicitParam(name = "rmsCapacity", value = "详细实体rmsCapacity", required = true, dataType = "RmsCapacity")
    @PostMapping(value = "/insertCapacity")
    public RESTfulResult insertCapacity(@RequestBody RmsCapacity rmsCapacity){
       int result = rmsCapacityService.insertCapacity(rmsCapacity);
       if (result==-1){
           return failed();
       }
        return success(result);
    }

    /**
     * 根据id更新运力信息
     * @param rmsCapacity
     * @return
     */

    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsCapacity信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short"),
            @ApiImplicitParam(name = "rmsCapacity", value = "详细实体rmsCapacity", required = true, dataType = "RmsCapacity")
    })
    @PostMapping(value = "/updateCapacity", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateCapacity( @RequestBody RmsCapacity rmsCapacity){
        int result = rmsCapacityService.updateCapacity(rmsCapacity);
        return success(result);
    }

    /**
     * 根据id删除运力信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short")
    @PostMapping(value = "/deleteCapacity/{id}")
    public RESTfulResult deleteCapacity(@PathVariable("id") BigDecimal id){
        return success(rmsCapacityService.deleteCapacity(id));
    }

    /**
     * 根据id获取运力信息
     * @param id
     * @return
     */
    @ApiOperation(value="获取运力详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getCapacityById/{id}")
    public RESTfulResult getCapacityById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> list= rmsCapacityService.getCapacityById(id);
        return success(list);
    }

    /*
    * 运力类型下拉框
    * */
    @GetMapping("/getCapacityTypeId")
    public RESTfulResult getCapacityTypeId(){
        return success(rmsCapacityService.getCapacityTypeId());
    }

    /*
    * 承运单位下拉框
    * */
    @GetMapping("/getCarrierId")
    public RESTfulResult getCarrierId(){
        return success(rmsCapacityService.getCarrierId());
    }

    /*
    *模糊查询运力表
    * */

    @ApiOperation(value = "模糊查询展示运力表", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getCapacityList")
    public RESTfulResult getCapacityList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String con) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_capacity_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsCapacityService.getCapacityList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_capacity_list");
            //添加id
            map.put("indexId", "capacityId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsCapacityService.getCapacityList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsCapacityService.getCapacityList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }
}
