package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsBidArea;
import com.steerinfo.dil.model.RmsCarrier;
import com.steerinfo.dil.service.impl.RmsBidAreaServiceImpl;
import com.steerinfo.dil.service.impl.RmsCarrierServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsCarrier RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-18 08:46
 * 类描述
 * 修订历史：
 * 日期：2021-11-18
 * 作者：generator
 * 参考：
 * 描述：RmsCarrier RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
    @RequestMapping("/${api.version}/rmscarrier")
public class RmsCarrierController extends BaseRESTfulController {

    @Autowired
    RmsCarrierServiceImpl rmsCarrierService;
    @Autowired
    RmsBidAreaServiceImpl rmsBidAreaService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 展示承运商信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "342", required = false, dataType = "BigDecimal"),
    })
    //@RequiresPermissions("rmscarrier:view")
    @PostMapping(value = "/getCarrierList")
    public RESTfulResult getCarrierList(@RequestBody(required = false) Map<String,Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        String con){
        if (mapValue==null){
            mapValue=new HashMap<>();
        }

        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_carrierr_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsCarrierService.getCarrierList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_carrierr_list");
            //添加id
            map.put("indexId", "carrierrId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsCarrierService.getCarrierList(mapValue);
        }

//        System.out.println(listTotal);

        System.out.println(listTotal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsCarrierService.getCarrierList(mapValue);
        //        将中标区域id转换为先对应的地方
        for (Map<String, Object> map: columnList){
            BigDecimal carrierBidAreaId=(BigDecimal) map.get("carrierBidAreaId");
            if (carrierBidAreaId!=null){
                //            根据id获取中标区域然后进行拼接
                Map<String, Object> map1=rmsBidAreaService.getBidAreaById(carrierBidAreaId);
                String carrierBidArea="";
                if (map1.get("bidAreaProvince")!=null){
                    carrierBidArea=carrierBidArea+(String)map1.get("bidAreaProvince");
                }
                if (map1.get("bidAreaCity")!=null){
                    carrierBidArea=carrierBidArea+(String)map1.get("bidAreaCity");
                }
                if (map1.get("bidAreaCount")!=null){
                    carrierBidArea=carrierBidArea+(String)map1.get("bidAreaCount");
                }
                if (map1.get("bidAreaCountry")!=null){
                    carrierBidArea=carrierBidArea+(String)map1.get("bidAreaCountry");
                }
                map.put("carrierBidArea",carrierBidArea);
            }
        }

        PageListAdd data = columnDataUtil.tableColumnData(apiId,listTotal,columnList);
        System.out.println(data);
        return success(data);
    }

    /**
     * 添加承运商信息
     * @param
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsCarrier对象创建")
    @ApiImplicitParam(name = "rmsCarrier", value = "详细实体rmsCarrier", required = true, dataType = "RmsCarrier")
    //@RequiresPermissions("rmscarrier:create")
    @PostMapping(value = "/insertCarrier")
    public RESTfulResult insertCarrier(@RequestBody(required = false) RmsCarrier rmsCarrier){
        int result = rmsCarrierService.insertCarrier(rmsCarrier);
        if (result==-1){
            return failed();
        }
        return success(result);
    }

    /**
     * 更改承运商信息
     * @param rmsCarrier
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsCarrier信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsCarrier", value = "详细实体rmsCarrier", required = true, dataType = "RmsCarrier")
    })
    //@RequiresPermissions("rmscarrier:update")
    @PostMapping(value = "/updateCarrier", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateCarrier(@RequestBody RmsCarrier rmsCarrier){
        int result = rmsCarrierService.updateCarrier(rmsCarrier);
        return success(result);
    }

    /**
     * 删除承运商信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmscarrier:delete")
    @PostMapping(value = "/deleteCarrier/{id}")//BigDecimal
    public RESTfulResult deleteCarrier(@PathVariable("id") BigDecimal id){

        return success(rmsCarrierService.deleteCarrier(id));
    }

    /**根据id值详细获取承运商信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getCarrierById/{id}")
    public RESTfulResult getCarrierById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsCarrierService.getCarrierById(id);
        for (Map<String, Object> map:list){
            String carrierTransportType=(String)map.get("carrierTransportType");
            if (carrierTransportType!=null){
                if (carrierTransportType.equals("危化品")){
                    map.put("carrierTransportType",1);
                }
                if (carrierTransportType.equals("其他")){
                    map.put("carrierTransportType",2);
                }
            }
        }
        return success(list);
    }

    /**
     * 根据id获取中标区域
     */
    @ApiOperation(value="展示中标区域信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "406", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "id", value = "中标id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getCarrierBidAreaList")
    public RESTfulResult getCarrierBidAreaList(@RequestBody(required = false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               String con){
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_bidareas_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsCarrierService.getCarrierBidAreaList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_bidareas_list");
            //添加id
            map.put("indexId", "bidAreasId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsCarrierService.getCarrierBidAreaList(mapValue);
        }
        System.out.println(listTotal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsCarrierService.getCarrierBidAreaList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId,listTotal, columnList);
        return success(data);
    }

}
