package com.steerinfo.dil.controller;


import com.steerinfo.dil.model.RmsDriverCapacity;
import com.steerinfo.dil.service.impl.RmsDriverCapacityServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:ZhouZhou
 * @CreateTime:2021/11/19 10:05
 * @Version:V1.0
 */
@RestController
@RequestMapping("/${api.version}/rmsdrivercapacity")
public class RmsDriverCapacityController extends BaseRESTfulController {
    @Autowired
    RmsDriverCapacityServiceImpl rmsDriverCapacityService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 展示司机排班信息
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示司机排班信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getDriverCapacityList")
    public RESTfulResult getDriverCapacityList(@RequestBody(required = false) Map<String,Object> mapVal,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId){
        List<Map<String,Object>> list = rmsDriverCapacityService.getDriverCapacityList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsDriverCapacityService.getDriverCapacityList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     *增加司机排班
     * @param
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsDriverCapacity对象创建")
    @ApiImplicitParam(name = "rmsDriverCapacity", value = "详细实体rmsDriverCapacity", required = true, dataType = "RmsDriverCapacity")
    @PostMapping(value = "/insertDriverCapacity")
    public RESTfulResult insertDriverCapacity(@RequestBody(required = false) RmsDriverCapacity rmsDriverCapacity){
        int result =rmsDriverCapacityService.insertDriverCapacity(rmsDriverCapacity);
        return success(result);
    }


    /**
     *更新司机排班
     * @param
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsDriverCapacity信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsDriverCapacity", value = "详细实体rmsDriverCapacity", required = true, dataType = "RmsrmsDriverCapacity")
    })
    @PostMapping(value = "/updateDriverCapacity", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateDriverCapacity(@RequestBody RmsDriverCapacity rmsDriverCapacity){
        int result = rmsDriverCapacityService.updateDriverCapacity(rmsDriverCapacity);
        return success(result);
    }

    /**
     *删除司机排班
     * @param id
     * @return
     */
        @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
        @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
        @PostMapping(value = "/deleteDriverCapacity/{id}")//BigDecimal
        public RESTfulResult deleteDriverCapacity(@PathVariable("id") BigDecimal id){
            int result=rmsDriverCapacityService.deleteDriverCapacity(id);
            return success(result);
        }

    /**
     * 根据id获取司机排班
     * @param id
     * @return
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getDriverCapacityById/{id}")
    public RESTfulResult getDriverCapacityById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> list= rmsDriverCapacityService.getDriverCapacityById(id);
        return success(list);
    }


    /*
     * 承运商id下拉框
     * */
    @GetMapping("/getCarrierId")
    public RESTfulResult getCarrierId(){
        return success(rmsDriverCapacityService.getCarrierId());
    }

    /*
    * 司机id下拉框
    * */
    @GetMapping("/getDriverId")
    public RESTfulResult getDriverId(){
        return success(rmsDriverCapacityService.getDriverId());
    }


    /*
    *运力类型id下拉框
    * */
    @GetMapping("/getCapacityTypeId")
    public RESTfulResult getCapacityTypeId(){
        return success(rmsDriverCapacityService.getCapacityTypeId());
    }


}
