package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsMaterial;
import com.steerinfo.dil.service.impl.RmsMaterialServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/22 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmsmaterial")
public class RmsMaterialController extends BaseRESTfulController {

    @Autowired
    RmsMaterialServiceImpl rmsMaterialService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;
    /**
     * 展示物资信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "335", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getMaterialList")
    public RESTfulResult getMaterialList(@RequestBody(required = false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String con){
        if (mapValue==null){
            mapValue=new HashMap<>();
        }

        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_material_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsMaterialService.getMaterialList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_material_list");
            //添加id
            map.put("indexId", "materialId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsMaterialService.getMaterialList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
            List<Map<String, Object>> columnList = rmsMaterialService.getMaterialList(mapValue);

        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }


    /**
     *添加物资信息
     * @param
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsMaterial对象创建")
    @ApiImplicitParam(name = "rmsMaterial", value = "详细实体rmsMaterial", required = true, dataType = "RmsMaterial")
    //@RequiresPermissions("rmsmaterial:create")
    @PostMapping(value = "/insertMaterial")
    public RESTfulResult insertMaterial(@RequestBody RmsMaterial rmsMaterial){
        int result = rmsMaterialService.insertMaterial(rmsMaterial);
        if (result==-1){
            return failed();
        }
        return success(result);
    }

    /**
     * 更新物资信息
     * @param
     * @param
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsMaterial信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsMaterial", value = "详细实体rmsMaterial", required = true, dataType = "RmsMaterial")
    })
    //@RequiresPermissions("rmsmaterial:update")
    @PostMapping(value = "/updateMaterial", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateMaterial(@RequestBody RmsMaterial rmsMaterial){
        int result = rmsMaterialService.updateMaterial(rmsMaterial);
        return success(result);
    }

    /**
     * 删除物资信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmsmaterial:delete")
    @PostMapping(value = "/deleteMaterial/{id}")//BigDecimal
    public RESTfulResult deleteMaterial(@PathVariable("id") BigDecimal id){

        return success(rmsMaterialService.deleteMaterial(id));
    }

    /**根据id值详细获取原材料信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getMaterialById/{id}")
    public RESTfulResult getMaterialById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsMaterialService.getMaterialById(id);
        return success(list);
    }

    /**
     * 下拉框获得材料类型Id
     */
    @GetMapping("/getMaterialTypeId")
    public RESTfulResult getMaterialTypeId(){
        return  success(rmsMaterialService.getMaterialTypeId());
    }

    /**
     * 下拉框获得计量Id
     * @return
     */
    @GetMapping("/getUnitOfMeasureId")
    public RESTfulResult getUnitOfMeasureId(){
        return  success(rmsMaterialService.getUnitOfMeasureId());
    }


}
