package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsCarDriver;
import com.steerinfo.dil.service.IRmsOilPriceService;
import com.steerinfo.dil.service.impl.RmsCarDriverServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import com.steerinfo.dil.model.RmsOilPrice;
import com.steerinfo.dil.service.IRmsOilPriceService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.math.BigDecimal;

/**
 * RmsOilPricea RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-23 05:01
 * 类描述
 * 修订历史：
 * 日期：2021-11-23
 * 作者：generator
 * 参考：
 * 描述：RmsOilPricea RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
/*@RestController
@RequestMapping("/${api.version}/rmsoilprices")
public class RmsOilPriceController extends BaseRESTfulController {

    @Autowired
    IRmsOilPriceService rmsOilPriceService;


}*/




@RestController
@RequestMapping("/${api.version}/rmsoilprice")
public class RmsOilPriceController extends BaseRESTfulController {
    @Autowired
    IRmsOilPriceService rmsOilPriceService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;



    /**
     * 展示油价信息
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    //测试成功
    @ApiOperation(value="展示油价信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "355", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getOilPriceList")
    public RESTfulResult getOilPriceList(@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize
                                          ){
        List<Map<String,Object>> list = rmsOilPriceService.getOilPriceList(mapVal);
        PageHelper.startPage(pageNum, pageSize);

        //分页查询数据
        List<Map<String, Object>> columnList = rmsOilPriceService.getOilPriceList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     *增加新油价
     * @param rmsOilPrice
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsOilPrice对象创建")
    @ApiImplicitParam(name = "rmsOilPrice", value = "详细实体rmsOilPrice", required = true, dataType = "RmsOilPrice")
    @PostMapping(value = "/insertOilPrice")
    public RESTfulResult insertOilPrice(@RequestBody(required = false) RmsOilPrice rmsOilPrice){
        int result = rmsOilPriceService.insertOilPrice(rmsOilPrice);
        return success(result);
    }


    /**
     *更新油价
     * @param rmsOilPrice
     * @return
     */

    @PostMapping(value = "/updateOilPrice", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateOilPrice(@RequestBody RmsOilPrice rmsOilPrice){
        int result = rmsOilPriceService.updateOilPrice(rmsOilPrice);
        return success(result);
    }

    //淘汰版本仅供参考
/*    @PostMapping(value = "/updateOilPriceById/{id}", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateOilPriceById(@RequestBody RmsOilPrice rmsOilPrice){
        int result = rmsOilPriceService.updateOilPrice(rmsOilPrice);
        return success(result);
    }*/


    /**
     *删除油价
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteOilPrice/{id}")//BigDecimal
    public RESTfulResult deleteOilPrice(@PathVariable("id") BigDecimal id){
        return success(rmsOilPriceService.deleteOilPrice(id));
    }

    /**
     * 根据id获取油价
     * @param id
     * @return
     */
    //测试成功

    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getOilPriceById/{id}")
    public RESTfulResult getOilPriceById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> map= rmsOilPriceService.getOilPriceById(id);
        return success(map);
    }


    /**
     * 油价类型下拉框
     * */
/*//未实现，保留
    @GetMapping("/getOilPriceTypeId")
    public RESTfulResult getOilPriceTypeId(){
        return success(rmsOilPriceService.getOilPriceTypeId());
    }
*/


    @ApiOperation(value = "油价模糊查询", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "355", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getOilPriceResultList")
    public RESTfulResult getOilPriceResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId,
                                                String con) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_oil_price_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsOilPriceService.getOilPriceList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_oil_price_list");
            //添加id
            map.put("indexId", "priceId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsOilPriceService.getOilPriceList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsOilPriceService.getOilPriceList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }



}