package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsPersonnel;
import com.steerinfo.dil.service.impl.RmsPersonnelServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsPersonnel RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-06 02:47
 * 类描述
 * 修订历史：
 * 日期：2021-11-06
 * 作者：hujiehuan
 * 参考：
 * 描述：RmsPersonnel RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/rmspersonnel")
public class RmsPersonnelController extends BaseRESTfulController {

    @Autowired
    RmsPersonnelServiceImpl rmsPersonnelService;


    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 展示人员信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示人员信息", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "apiId", value = "341", required = false, dataType = "BigDecimal"),
    })
    //@RequiresPermissions("rmspersonnel:view")
    @PostMapping(value = "/getPersonnelList")
    public RESTfulResult getPersonnelList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          String con){

        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_personnel_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsPersonnelService.getPersonnelList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_personnel_list");
            //添加id
            map.put("indexId", "personnelId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsPersonnelService.getPersonnelList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsPersonnelService.getPersonnelList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId,listTotal,columnList);
        return success(data);
    }

    /**
     * 添加人员信息
     * @param rmsPersonnel
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsPersonnel对象创建")
    @ApiImplicitParam(name = "rmsPersonnel", value = "详细实体rmsPersonnel", required = false, dataType = "RmsPersonnel")
    //@RequiresPermissions("rmspersonnel:create")
    @PostMapping(value = "/insertPersonnel")
    public RESTfulResult insertPersonnel(@RequestBody RmsPersonnel rmsPersonnel){
        int result=rmsPersonnelService.insertPersonnel(rmsPersonnel);
        if (result==-1){
            return failed();
        }
        return success(result);
    }
    /**
     * 添加托运人
     */

    /**
     * 更新人员信息
     * @param rmsPersonnel
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsPersonnel信息来更新详细信息")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
        @ApiImplicitParam(name = "rmsPersonnel", value = "详细实体rmsPersonnel", required = true, dataType = "RmsPersonnel")
    })
    //@RequiresPermissions("rmspersonnel:update")
    @PostMapping(value = "/updatePersonnel", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updatePersonnel(@RequestBody RmsPersonnel rmsPersonnel){
        int result=rmsPersonnelService.updatePersonnel(rmsPersonnel);
        return success(result);
    }

    /**
     * 删除人员信息
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmspersonnel:delete")
    @PostMapping(value = "/deletePersonnel/{id}")//BigDecimal
    public RESTfulResult deletePeronnel(@PathVariable ("id") BigDecimal id ){

      return success(rmsPersonnelService.deletePersonnel(id));
    }

    /**根据id值详细获取人员信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getPersonnelById/{id}")
    public RESTfulResult getPersonnelById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsPersonnelService.getPersonnelById(id);
        System.out.println(list);
        return success(list);
    }
    /**
     * 下拉框获得托运人信息
     */
    @GetMapping("/getShipperId")
    public RESTfulResult getShipperId(){
        return  success(rmsPersonnelService.getShipperId());
    }

}
