package com.steerinfo.dil.controller;

import com.steerinfo.dil.model.RmsPort;
import com.steerinfo.dil.service.impl.RmsPortServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-11-15 15:13
 */
@RestController
@RequestMapping("/${api.version}/rmsPort")
public class RmsPortController extends BaseRESTfulController {

    @Autowired
    RmsPortServiceImpl rmsPortService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 新增港口
     * @param rmsPort
     * @return
     */
    @PostMapping("/insertPort")
    public RESTfulResult insertPort(@RequestBody(required = true)RmsPort rmsPort){

       Integer integer = rmsPortService.insertPort(rmsPort);
       if (
               integer!=1
       ){
           return failed();
       }
        else{
           return success();
       }

    }

    /**
     * 修改港口
     * @param rmsPort
     * @return
     */
    @PostMapping("/editPort")
    public RESTfulResult editPort(@RequestBody(required = true)RmsPort rmsPort){

        Integer integer = rmsPortService.updatePort(rmsPort);
        if (
                integer!=1
        ){
            return failed();
        }
        else{
            return success();
        }

    }


    /**
     * 删除港口
     * @param portId
     * @return
     */
    @PostMapping("/deletePort/{portId}")
    public RESTfulResult deletePort(@PathVariable("portId") BigDecimal portId){

        Integer integer = rmsPortService.deletePort(portId);
        if (
                integer!=1
        ){
            return failed();
        }
        else{
            return success();
        }

    }


    @ApiOperation(value="展示港口信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getPort")
    public RESTfulResult getPort(@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId){
        List<Map<String,Object>> list = rmsPortService.getPort(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsPortService.getPort(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 港口类型ID
     * @return
     */
    @GetMapping("/getPortType")
    public RESTfulResult getPortType(){
        return success(rmsPortService.getPortType());
    }
}
