package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsSupplier;
import com.steerinfo.dil.service.impl.RmsSupplierServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJieHuan
 * @GreateTime:2021/11/09 17:24
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmssupplier")
public class RmsSupplierController extends BaseRESTfulController {

    @Autowired
    RmsSupplierServiceImpl rmsSupplierService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 展示供应商信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示供应商信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "343", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getSupplierList")
    public RESTfulResult getSupplierList(@RequestBody(required = false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String con){
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_supplier_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsSupplierService.getSupplierList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_supplier_list");
            //添加id
            map.put("indexId", "supplierId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsSupplierService.getSupplierList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsSupplierService.getSupplierList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    /**
     * 添加供应商
     */
    @ApiOperation(value="创建", notes="根据RmsSupplier对象创建")
    @ApiImplicitParam(name = "rmsSupplier", value = "详细实体rmsSupplier", required = true, dataType = "RmsSupplier")
    //@RequiresPermissions("rmssupplier:create")
    @PostMapping(value = "/insertSupplier")
    public RESTfulResult insertSupplier(@RequestBody RmsSupplier rmsSupplier){
        int result= rmsSupplierService.insertSupplier(rmsSupplier);
        if (result==-1){
            return failed();
        }
        return success(result);
    }

    /**
     * 通过id值来更新信息
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsSupplier信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsSupplier", value = "详细实体rmsSupplier", required = true, dataType = "RmsSupplier")
    })
    //@RequiresPermissions("rmssupplier:update")
    @PostMapping(value = "/updateSupplier", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateSupplier(@RequestBody RmsSupplier rmsSupplier){
        int result= rmsSupplierService.updateSupplier(rmsSupplier);
        return success(result);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmssupplier:delete")
    @PostMapping(value = "/deleteSupplier/{id}")//BigDecimal
    public RESTfulResult deleteSupplier(@PathVariable("id") BigDecimal id){

        return success(rmsSupplierService.deleteSupplier(id));
    }

    /**根据id值详细获取供应商信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getSupplierById/{id}")
    public RESTfulResult getSupplierById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsSupplierService.getSupplierById(id);
        return success(list);
    }
}
