package com.steerinfo.dil.controller;


import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsMaterial;
import com.steerinfo.dil.model.RmsTruckCalculate;
import com.steerinfo.dil.model.RmsTruckCalculateMaterial;
import com.steerinfo.dil.service.impl.RmsMaterialServiceImpl;
import com.steerinfo.dil.service.impl.RmsTruckCalculateServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:ZhouZhou
 * @CreateTime:2021/11/12 14:12
 * @Version:V1.0
 */
@RestController
@RequestMapping("/${api.version}/rmstruckcalculate")
public class RmsTruckCalculateController extends BaseRESTfulController {

    @Autowired
    RmsTruckCalculateServiceImpl rmsTruckCalculateService;

    @Autowired
    RmsMaterialServiceImpl rmsMaterialService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     *增加汽车衡
     * @param
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsCarDriver对象创建")
    @ApiImplicitParam(name = "rmsTruckCalculate", value = "详细实体rmsTruckCalculate", required = true, dataType = "RmsTruckCalculate")
    @PostMapping(value = "/insertTruckCalculate")
    public RESTfulResult insertTruckCalculate(@RequestBody(required = false) Map<String, Object> map){
        int result = rmsTruckCalculateService.insertTruckCalculate(map);
        return success(result);
    }

    /*
    * 增加汽车衡物资
    * */

    @ApiOperation(value="创建")
    @ApiImplicitParam(name = "rmsTruckCalculate", value = "详细实体rmsTruckCalculate", required = true, dataType = "RmsTruckCalculate")
    @PostMapping(value = "/insertTruckCalculateOfMaterial")
    public RESTfulResult insertTruckCalculateOfMaterial(@RequestBody(required = false) RmsTruckCalculateMaterial rmsTruckCalculateMaterial){
        int result = rmsTruckCalculateService.insertTruckCalculateOfMaterial(rmsTruckCalculateMaterial);
        return success(result);
    }
    /**
     *更新汽车衡
     * @param
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsCarDriver信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsTruckCalculate", value = "详细实体rmsTruckCalculate", required = true, dataType = "RmsTruckCalculate")
    })
    @PostMapping(value = "/updateTruckCalculate", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateTruckCalculate(@RequestBody Map<String,Object> map){
        int result = rmsTruckCalculateService.updateTruckCalculate(map);
        return success(result);
    }

    /**
     *删除汽车衡
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteTruckCalculate/{id}")//BigDecimal
    public RESTfulResult deleteTruckCalculate(@PathVariable("id") BigDecimal id){

        return success(rmsTruckCalculateService.deleteTruckCalculate(id));
    }

    /*
    * 删除汽车衡物资中间表
    * */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteTruckCalculateMaterial/{id}")//BigDecimal
    public RESTfulResult deleteTruckCalculateMaterial(@PathVariable("id") BigDecimal id){

        return success(rmsTruckCalculateService.deleteTruckCalculateMaterial(id));
    }
    /*
    * 根据id查找汽车衡
    * */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getTruckCalculateById/{id}")
    public RESTfulResult getTruckCalculateById(@PathVariable("id") BigDecimal id){
        List<Map<String,Object>> list= rmsTruckCalculateService.getTruckCalculateById(id);
        return success(list);
    }


    @ApiOperation(value = "模糊查询汽车衡", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getTruckCalculateList")
    public RESTfulResult getTruckCalculateList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId,
                                                String con) {
        if (mapValue==null){
            mapValue=new HashMap<>();
        }
        //框计算
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_truck_calculate_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> listTotal = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            listTotal = rmsTruckCalculateService.getTruckCalculateList(null);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_truck_calculate_list");
            //添加id
            map.put("indexId", "truckCalculateId");
            listTotal.add(map);
            //新建索引
            String s = JSON.toJSONString(listTotal);
            esFeign.insertIndex(listTotal);
            //删除
            listTotal.remove(listTotal.size() - 1);
        }
        if (listTotal == null) {
            listTotal = rmsTruckCalculateService.getTruckCalculateList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsTruckCalculateService.getTruckCalculateList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    @ApiOperation(value="展示物资信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "id", value = "物资id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getCalculateOfMaterialList")
    public RESTfulResult getCalculateOfMaterialList(@RequestBody(required = false) Map<String,Object> mapVal,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId,
                                                    BigDecimal truckCalculateId ){
        if (mapVal==null){
            mapVal=new HashMap<>();
        }
        if(truckCalculateId!=null) {
            mapVal.put("truckCalculateId", truckCalculateId);
        }
        List<Map<String,Object>> list =rmsMaterialService.getCalculateOfMaterialList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsMaterialService.getCalculateOfMaterialList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId,list, columnList);
        return success(data);
    }


}
