package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsBidAreaMapper;
import com.steerinfo.dil.mapper.RmsCarrierMapper;
import com.steerinfo.dil.model.RmsCarrier;
import com.steerinfo.dil.model.RmsShipper;
import com.steerinfo.dil.service.IRmsCarrierService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsCarrier服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-18 08:46
 * 类描述
 * 修订历史：
 * 日期：2021-11-18
 * 作者：generator
 * 参考：
 * 描述：RmsCarrier服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "rmsCarrierService")
public class RmsCarrierServiceImpl implements IRmsCarrierService {

    @Autowired
    private RmsCarrierMapper rmsCarrierMapper;

    @Autowired
    private RmsBidAreaMapper rmsBidAreaMapper;
    /**
     * 查询承运商表
     * @return
     */

    public List<Map<String, Object>> getCarrierList(Map<String, Object> mapVal) {
        return rmsCarrierMapper.getCarrierList(mapVal);
    }

    /**
     *  删除承运商
     * @param id
     * @return
     */
    @Override
    public int deleteCarrier(BigDecimal id) {
        RmsCarrier rmsCarrier=rmsCarrierMapper.selectByPrimaryKey(id);
        rmsCarrier.setDeleted(new BigDecimal(1));
        return rmsCarrierMapper.updateByPrimaryKeySelective(rmsCarrier);
    }

    /**
     * 修改承运商信息
     * @param rmsCarrier
     * @return
     */
    @Override
    public int updateCarrier(RmsCarrier rmsCarrier) {
        String transportType=rmsCarrier.getCarrierTransportType();
        if (transportType!=null){
            if (transportType.equals("1")){
                rmsCarrier.setCarrierTransportType("危化品");
            }
            if(transportType.equals("2")){
                rmsCarrier.setCarrierTransportType("其他");
            }
        }
        rmsCarrier.setUpdateUsername("admin");
        rmsCarrier.setUpdateTime(new Date());
        rmsCarrier.setRegisterDate(rmsCarrier.getRegisterDate());

        return rmsCarrierMapper.updateByPrimaryKeySelective(rmsCarrier);
    }

    /**
     * 添加承运商信息
     * @param rmsCarrier
     * @return
     */
    @Override
    public int insertCarrier(RmsCarrier rmsCarrier) {
        int i=0;
        String carrierName=rmsCarrier.getCarrierName();
        Map<String, Object> map=new HashMap<>();
        map.put("carrierName",carrierName);
        List<RmsCarrier> rmsCarriers=rmsCarrierMapper.selectByParameters(map);
        if (rmsCarriers.size()!=0){
            i=-1;
        }
        else {
            String transportType = rmsCarrier.getCarrierTransportType();
            Date date = new Date(0);
            if (!rmsCarrier.getRegisterDate().equals(date)) {
                if (transportType != null) {
                    if (transportType.equals("1")) {
                        rmsCarrier.setCarrierTransportType("危化品");
                    }
                    if (transportType.equals("2")) {
                        rmsCarrier.setCarrierTransportType("其他");
                    }
                }
                rmsCarrier.setInsertTime(new Date());
                rmsCarrier.setInsertUsername("admin");
                rmsCarrier.setDeleted(new BigDecimal(0));
                rmsCarrier.setCarrierId(rmsCarrierMapper.getCarrierId());
                i+=rmsCarrierMapper.insertSelective(rmsCarrier);
            }else{
                rmsCarrier.setRegisterDate(null);
            }
        }

        return i;
    }

    /**
     * 通过id值查询承运商信息
     * @param id
     * @return
     */
    @Override
    public List<Map<String, Object>> getCarrierById(BigDecimal id) {
        return rmsCarrierMapper.selectCarrierById(id);
    }

    /**
     * 展示中标区域
     */
    @Override
    public List<Map<String, Object>> getCarrierBidAreaList(Map<String, Object> mapVal) {
        return rmsBidAreaMapper.getCarrierBidAreaList();
    }
}
