package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsGatepostMapper;
import com.steerinfo.dil.mapper.RmsGatepostRulesMapper;
import com.steerinfo.dil.model.RmsCarrier;
import com.steerinfo.dil.model.RmsGatepost;
import com.steerinfo.dil.model.RmsGatepostRules;
import com.steerinfo.dil.service.IRmsGatepostService;
import com.steerinfo.dil.util.DataChange;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * RmsGatepost服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-12 11:51
 * 类描述
 * 修订历史：
 * 日期：2021-11-12
 * 作者：HuJieHuan
 * 参考：
 * 描述：RmsGatepost服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "rmsGatepostService")
public class RmsGatepostServiceImpl implements IRmsGatepostService {
    @Autowired
    private RmsGatepostMapper rmsGatepostMapper;
    @Autowired
    private RmsGatepostRulesMapper rmsGatepostRulesMapper;

//    时间转换工具
    Date startTime;
    Date endTime;
    SimpleDateFormat simpleDateFormat=new SimpleDateFormat("HH:mm");
    /**
     * 查询所有的门岗信息
     * @param mapVal
     * @return
     */
    @Override
    public List<Map<String, Object>> getGatepostList(Map<String, Object> mapVal){
        return rmsGatepostMapper.getGatepostList(mapVal);
    }

    /**
     * 删除门岗信息
     * @param gatepostId
     * @return
     */
    @Override
    public int deleteGatepost(BigDecimal gatepostId) {
        RmsGatepost rmsGatepost=rmsGatepostMapper.selectByPrimaryKey(gatepostId);
        rmsGatepost.setDeleted(new BigDecimal(1));
        return rmsGatepostMapper.updateByPrimaryKeySelective(rmsGatepost);
    }

    /**
     * 更改门岗信息
     * @param mapValue
     * @return
     */
    @Override
    public int updateGatepost(LinkedHashMap<String, Object> mapValue){
        //        创建一个变量i用来统计所有的实体类的更新结果
        int i=0;
//        使用三个ListMap来接收前端的数据
        Map<String, Object> map1= (Map<String, Object>) mapValue.get("gatepost");
        List<Map<String, Object>> map2= (List<Map<String, Object>>) mapValue.get("material");
        Map<String, Object> map3=(Map<String, Object>)mapValue.get("entityOutTypeLists");
        //        遍历进出类型集合，将所有的进出类型id插入到规则表中
        List<String> entityOutTypeList= (List<String>) map3.get("rulesGatepostEntityOutType");
        RmsGatepost rmsGatepost=new RmsGatepost();
//        添加规则实体类
//        遍历原料集合,将所有的原料id插入到规则表中
        for (Map<String, Object> material:map2){
            for (String entityOutType : entityOutTypeList) {
                RmsGatepostRules rmsGatepostRules=new RmsGatepostRules();
                Integer rulesGatepostEntityOutType = null;
                if (entityOutType.equals("进")) {
                    rulesGatepostEntityOutType = 0;
                }
                if (entityOutType.equals("出")){
                    rulesGatepostEntityOutType = 1;
                }
                rmsGatepostRules.setMaterialId(DataChange.dataToBigDecimal(material.get("materialId")));
                rmsGatepostRules.setRulesGatepostEntryOutType(new BigDecimal(rulesGatepostEntityOutType));
                //        将开门时间和关门时间转换为字符串
                rmsGatepostRules.setRulesGatepostStartTime(simpleDateFormat.format(startTime));
                rmsGatepostRules.setRulesGatepostEndTime(simpleDateFormat.format(endTime));
                //        获取门岗id
                rmsGatepostRules.setGatepostId(rmsGatepostMapper.getGatepostMaxId());
                rmsGatepostRules.setInsertTime(new Date());
                rmsGatepostRules.setInsertUsername("admin");
                rmsGatepostRules.setDeleted(new BigDecimal(0));
                rmsGatepostRules.setRulesId(rmsGatepostRulesMapper.getRulesId());
                Integer vehicleTypeId=(Integer)map1.get("vehicleTypeId");
                rmsGatepostRules.setVehicleTypeId(new BigDecimal(vehicleTypeId));
                i+=rmsGatepostRulesMapper.updateByPrimaryKeySelective(rmsGatepostRules);
            }
        }
//        添加门岗实体类
        rmsGatepost.setUpdateTime(new Date());
        rmsGatepost.setUpdateUsername("admin");
        rmsGatepost.setDeleted(new BigDecimal(0));
        rmsGatepost.setGatepostId(rmsGatepostMapper.getGatepostId());
        rmsGatepost.setGatepostLatitude((String) map1.get("gatepostLatitude"));
        rmsGatepost.setGatepostLongitude((String)map1.get("gatepostLongitude"));
        rmsGatepost.setGatepostName((String)map1.get("gatepostName"));
        Integer gatepostPriority=Integer.parseInt((String)map1.get("gatepostPriority"));
        rmsGatepost.setGatepostPriority(new BigDecimal(gatepostPriority));
        i+= rmsGatepostMapper.updateByPrimaryKeySelective(rmsGatepost);

        return i;
    }

    /**
     * 插入门岗信息
     * @param rmsGatepost
     * @return
     */
    @Override
    public int insertGatepost(RmsGatepost rmsGatepost){
        int i=0;
        String gatepostName=rmsGatepost.getGatepostName();
        Map<String, Object> map=new HashMap<>();
        map.put("gatepostName",gatepostName);
        List<RmsGatepost> rmsGateposts=rmsGatepostMapper.selectByParameters(map);
        if (rmsGateposts.size()!=0){
            i=-1;
        }
        else {
            rmsGatepost.setInsertUsername("admin");
            rmsGatepost.setInsertTime(new Date());
            rmsGatepost.setDeleted(new BigDecimal(0));
            rmsGatepost.setGatepostId(rmsGatepostMapper.getGatepostId());
            i += rmsGatepostMapper.insertSelective(rmsGatepost);
        }
        return i;
    }


    /**
     * 根据门岗id获得门岗规则详细信息
     */
    @Override
    public List<Map<String, Object>> getGatepostRulesById(BigDecimal gatepostId) {
        return rmsGatepostMapper.getGatepostRulesById(gatepostId);
    }

    /**
     * 获取原料Id
     * @return
     */
    @Override
    public List<Map<String, Object>> getMaterialId() {
        return rmsGatepostRulesMapper.getMaterialId();
    }


    /**
     * 获取车辆类型Id
     * @return
     */
    @Override
    public List<Map<String, Object>> getVehicleTypeId() {
        return rmsGatepostRulesMapper.getVehicleTypeId();
    }


    /**
     * 根据规则Id删除规则
     */
    @Override
    public int deleteGatepostRules(BigDecimal rulesId) {
        RmsGatepostRules rmsGatepostRules=rmsGatepostRulesMapper.selectByPrimaryKey(rulesId);
        rmsGatepostRules.setDeleted(new BigDecimal(1));
        return rmsGatepostRulesMapper.updateByPrimaryKeySelective(rmsGatepostRules);
    }

    /**
     * 添加规则
     * @param mapValue
     * @return
     */
    @Override
    public int insertGatepostRule(Map<String, Object> mapValue) {
        int i=0;
        RmsGatepostRules rmsGatepostRules=new RmsGatepostRules();
        List<Integer> list= (List<Integer>) mapValue.get("materialIds");
        Map<String, Object>map2=(Map<String,Object>)mapValue.get("rmsGatepostRules");
        Map<String, Object> map3=(Map<String, Object>)mapValue.get("rulesGatepostEntityOutTypeList");

        List<String> entityOutTypeList=(List<String>)map3.get("rulesGatepostEntityOutTypeStr");
        for (Integer materialId : list) {
            rmsGatepostRules.setMaterialId(new BigDecimal(materialId));
            for (String entityOutTypeStr:entityOutTypeList){
                if (entityOutTypeStr.equals("进")){
                    rmsGatepostRules.setRulesGatepostEntryOutType(new BigDecimal(0));
                }
                if (entityOutTypeStr.equals("出")){
                    rmsGatepostRules.setRulesGatepostEntryOutType(new BigDecimal(1));
                }
                String gatepostId=(String) map2.get("gatepostId");
                rmsGatepostRules.setGatepostId(new BigDecimal(gatepostId));
                rmsGatepostRules.setRulesGatepostStartTime((String) map2.get("rulesGatepostStartTime"));
                rmsGatepostRules.setRulesGatepostEndTime((String) map2.get("rulesGatepostEndTime"));
                Integer vehicleTypeId=(Integer) map2.get("vehicleTypeId");
                rmsGatepostRules.setVehicleTypeId(new BigDecimal(vehicleTypeId));
                rmsGatepostRules.setInsertUsername("admin");
                rmsGatepostRules.setInsertTime(new Date());
                rmsGatepostRules.setDeleted(new BigDecimal(0));
                rmsGatepostRules.setRulesId(rmsGatepostRulesMapper.getRulesId());
                i+=rmsGatepostRulesMapper.insertSelective(rmsGatepostRules);
            }
        }

        return i;
    }

    /**
     * 根据id获取门岗名
     * @param gatepostId
     * @return
     */
    @Override
    public Map<String, Object> getGatepostName(BigDecimal gatepostId) {
        return rmsGatepostMapper.getGatepostName(gatepostId);
    }
}
